[−][src]Function raspberry_web::app::create_app
pub fn create_app(app_state: AppState) -> App<AppState>
creates and returns the app after mounting all routes/resources
pub fn create_app(app_state: AppState) -> App<AppState>
creates and returns the app after mounting all routes/resources